@@ -23,7 +23,7 @@ WS_CURRENT_APPS = "apps/status"
 
 # REST Constants
 REST_BASE_URL = "http://{0}:{1}/as/{2}"
-REST_CHANNEL_LIST = "services"
+REST_CHANNEL_LIST = "services/{0}/{1}"
 REST_FAVOURITES = "services/favourites"
 REST_RECORDING_DETAILS = "pvr/details/{0}"
 REST_RECORDINGS_LIST = "pvr/?limit={0}&offset={1}"
